from selenium import webdriver
from selenium.webdriver.edge.service import Service
from selenium.webdriver.edge.options import Options
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC

from jbtutils_selenium.constants import DRIVERS_FOLDER
import pathlib

script_directory = pathlib.Path().absolute()

EDGE = None
def open(profile_dir=None):
    ser = Service(DRIVERS_FOLDER+'\msedgedriver.exe')
    op = Options()
    op.add_argument('--log-level=3')
    if profile_dir:
        op.add_argument(f'user-data-dir={script_directory}\\{profile_dir}')
    global EDGE
    EDGE = webdriver.Edge(service=ser, options=op)
    EDGE.maximize_window()
    return EDGE

def wait(secs=10):
    return WebDriverWait(EDGE, secs)

def navigate_to(url):
    EDGE.get(url)

def switch_to_frame(iframe):
    return EDGE.switch_to.frame(iframe)

def set_page_load_timeout(secs):
    EDGE.set_page_load_timeout(secs)

def set_page_load_strategy(strategy):
    EDGE.capabilities['pageLoadStrategy'] = strategy

def set_implicit_wait(secs):
    EDGE.implicitly_wait(secs)

def execute_js(js_str, return_val=False):
    if return_val:  return EDGE.execute_script('return '+js_str)
    else:           EDGE.execute_script(js_str)

def execute_js_on_element(element, js_str):
    EDGE.execute_script(js_str, element)



def accept_alert():
    wait().until(EC.alert_is_present())
    EDGE.switch_to.alert.accept()

    

def find_elements_by_name(name):
    return EDGE.find_elements_by_name(name)

def find_elements_by_xpath(xpath):
    return EDGE.find_elements_by_xpath(xpath)

def find_elements_by_link_text(text):
    return EDGE.find_elements_by_link_text(text)

def find_elements_by_partial_link_text(text):
    return EDGE.find_elements_by_partial_link_text(text)

def find_elements_by_tag_name(tag_name):
    return EDGE.find_elements_by_tag_name(tag_name)

def find_elements_by_class_name(class_name):
    return EDGE.find_elements_by_class_name(class_name)

def find_elements_by_css_selector(selector):
    return EDGE.find_elements_by_css_selector(selector)


def get_current_window():
    return EDGE.current_window_handle

def get_windows():
    return EDGE.window_handles

def get_window(index):
    return EDGE.window_handles[index]

def switch_to_window(window):
    return EDGE.switch_to.window(window)

def get_current_window_title():
    return EDGE.title

def get_current_url():
    return EDGE.current_url

from selenium.webdriver.common.action_chains import ActionChains

def get_actions():
    return ActionChains(EDGE)