import logging
from time import time, sleep

from selenium.webdriver.common.by import By
from selenium.webdriver.support import expected_conditions as EC
from selenium.common.exceptions import TimeoutException

from jbtutils_selenium.drivers.edge import wait, get_current_url


def wait_for_element(val, by='xpath', wait_secs=10, ignore_error=False, condition='present'):
    logging.debug(f'Waiting for element, searching by {by} and condition {condition}')

    search_by = By.XPATH
    if      by == 'name':       search_by = By.NAME
    elif    by == 'id':         search_by = By.ID
    elif    by == 'class':      search_by = By.CLASS_NAME
        
    try:
        if      condition == 'present':                 return wait(wait_secs).until(EC.presence_of_element_located((search_by, val)))
        elif    condition == 'visibile':                return wait(wait_secs).until(EC.visibility_of_element_located((search_by, val)))
        elif    condition == 'clickable':               return wait(wait_secs).until(EC.element_to_be_clickable((search_by, val)))
        elif    condition == 'alert present':           return wait(wait_secs).until(EC.alert_is_present((search_by, val)))
        elif    condition == 'frame available':         return wait(wait_secs).until(EC.frame_to_be_available_and_switch_to_it((search_by, val)))
        elif    condition == 'new window':              return wait(wait_secs).until(EC.new_window_is_opened())
        elif    condition == 'frame available':         return wait(wait_secs).until(EC.element_selection_state_to_be((search_by, val)))
        elif    condition == 'not present':             return wait(wait_secs).until_not(EC.presence_of_element_located((search_by, val)))
        elif    condition == 'not visible':             return wait(wait_secs).until_not(EC.visibility_of_element_located((search_by, val)))

    except TimeoutException:
        logging.debug(f'After {wait_secs} seconds element did not appear')
        if ignore_error:    
            logging.debug(f'Ignoring error due to {ignore_error=}')
            return None
        else:               
            logging.exception('Timedout waiting for element')
            raise TimeoutException

def wait_for_text(val, text, by='xpath', wait_secs=10, ignore_error=False):
    search_by = By.XPATH
    if      by == 'name':       search_by = By.NAME
    elif    by == 'id':         search_by = By.ID
        
    try:
        return wait(wait_secs).until(EC.text_to_be_present_in_element((search_by, val), text))
    except TimeoutException:
        if ignore_error:    return None
        else:               raise TimeoutException


def wait_for_new_window(num_windows=2, wait_secs=10, ignore_error=False):
    logging.debug(f'Waiting for new window')
    try:
        return wait(wait_secs).until(EC.number_of_windows_to_be(num_windows))
    except TimeoutException:
        if ignore_error:    return None
        else:               raise TimeoutException


def wait_for_window_title_contains(text, wait_secs=10, ignore_error=False):
    logging.debug(f'Waiting for window to contain in the title: {text}')
    try:
        return wait(wait_secs).until(EC.title_contains(text))
    except TimeoutException:
        if ignore_error:    return None
        else:               raise TimeoutException

def wait_for_window_url_contains(url, wait_secs=10, ignore_error=False, interval=1):
    logging.debug(f'Waiting for window url to contain: {url}')

    initial_time = time()
    current_url = None
    while True:
        current_url = get_current_url()
        if url in current_url:
            return True
        
        if time()-initial_time >= wait_secs:
            if ignore_error:    return None
            else:               raise TimeoutException
            
        sleep(interval)
